#  Load needed libraries
library(tidyverse)
library(readxl)
# Load data
data0 <- read_xlsx("../data/S1 extra_TMPRSS2_muts.xlsx")

# Extract frequencies, scale and clean the dataset
# [1] THis is selecting all the clinical-data_genotype columns
# [2] This is needed because our ordering is the inverse of severity
data_n <- data0 %>%
   slice(15, 25) %>%
   select(contains("/")) %>% # [1]
   mutate(Mutation = c("G296G", "V197M")) %>%
   pivot_longer(-Mutation) %>%
   separate(name, into = c("cc", "Zigosity"), sep = "_") %>%
   mutate(cc = seq(5, 1)[as.integer(cc) + 1], # [2]
          Zigosity = case_when(Zigosity == "0/0" ~ "wt",
                               Zigosity == "1/1" ~ "omo",
                               Zigosity == "0/1" ~ "etero",
                               )) %>%
   unite(muzig, Mutation, Zigosity) %>%
   pivot_wider(names_from = muzig, values_from = value)  %>%
   mutate(V197M_Both = V197M_etero + V197M_omo,
          G296G_Both = G296G_etero + G296G_omo,
          V197M_Both_rel = V197M_Both   / (V197M_Both + V197M_wt) * 100,
          V197M_omo_rel = V197M_omo     / (V197M_Both + V197M_wt) * 100,
          V197M_etero_rel = V197M_etero / (V197M_Both + V197M_wt) * 100,
          G296G_Both_rel = G296G_Both   / (G296G_Both + G296G_wt) * 100,
          G296G_omo_rel = G296G_omo     / (G296G_Both + G296G_wt) * 100,
          G296G_etero_rel = G296G_etero / (G296G_Both + G296G_wt) * 100,
          ) %>%
   select(cc, contains("_rel")) %>%
   pivot_longer(-cc, values_to = "relval")  %>%
   separate(name, into = c("Mutation", "Zigosity")) %>%
  nest_by(Mutation, Zigosity)


# Calculate linear regression for each gmut group
data1_lms <- data_n %>%
  mutate(model = list(lm(relval ~ cc, data = data)))

# Function for extraction of confidence intervals
ci_calc <- function(ind) {
  model <- data1_lms$model[[ind]]
  xrange <- c(1, 5) #this is the range of cc (clinical categories)
  xseq <- seq(from = xrange[1], to = xrange[2])
  loess_df <- predict(model, newdata = data.frame(cc = xseq),
                      interval = "confidence")
  loess_df <- list(loess_df)
  names(loess_df) <- paste(data1_lms$Mutation[ind], data1_lms$Zigosity[ind])
  return(loess_df)
}

# Fitted values and confidence intervals
res2 <- lapply(seq_len(nrow(data1_lms)), ci_calc)
